[zorg] r258770 - Added clang build for libomp-clang-x86_64-linux-debian buildbot: http://lists.llvm.org/pipermail/openmp-dev/2016-January/001006.html

Galina Kistanova via llvm-commits llvm-commits at lists.llvm.org
Mon Jan 25 17:40:42 PST 2016


Author: gkistanova
Date: Mon Jan 25 19:40:41 2016
New Revision: 258770

URL: http://llvm.org/viewvc/llvm-project?rev=258770&view=rev
Log:
Added clang build for libomp-clang-x86_64-linux-debian buildbot: http://lists.llvm.org/pipermail/openmp-dev/2016-January/001006.html

Patch by Fedorova Vera.

Modified:
    zorg/trunk/zorg/buildbot/builders/Libiomp5Builder.py

Modified: zorg/trunk/zorg/buildbot/builders/Libiomp5Builder.py
URL: http://llvm.org/viewvc/llvm-project/zorg/trunk/zorg/buildbot/builders/Libiomp5Builder.py?rev=258770&r1=258769&r2=258770&view=diff
==============================================================================
--- zorg/trunk/zorg/buildbot/builders/Libiomp5Builder.py (original)
+++ zorg/trunk/zorg/buildbot/builders/Libiomp5Builder.py Mon Jan 25 19:40:41 2016
@@ -42,6 +42,14 @@ def getLibompCMakeBuildFactory(clean=Tru
                   defaultBranch='trunk',
                   workdir=llvm_srcdir))
 
+    # Get clang  if c/c++ compilers is clang/clang++
+    if c_compiler == "clang":
+        f.addStep(SVN(name='svn-clang',
+                      mode='update',
+                      baseURL='http://llvm.org/svn/llvm-project/cfe/',
+                      defaultBranch='trunk',
+                      workdir='%s/tools/clang' % llvm_srcdir))
+
     # Clean directory, if requested.
     if clean:
         f.addStep(ShellCommand(name="clean",
@@ -61,16 +69,24 @@ def getLibompCMakeBuildFactory(clean=Tru
                            workdir=llvm_builddir,
                            env=merged_env))
 
-    # Make llvm utils
-    f.addStep(WarningCountingShellCommand(name='make llvm utils build',
-                                          command=['make', 'LLVMX86Utils', '-j8'],
-                                          haltOnFailure=True,
-                                          description='make llvm utils build',
-                                          workdir=llvm_builddir,
-                                          env=merged_env))
+    # Make clang build or just llvm utils build
+    if c_compiler == "clang": 
+        f.addStep(WarningCountingShellCommand(name='make clang build',
+                                              command=['make', '-j8'],
+                                              haltOnFailure=True,
+                                              description='make clang build',
+                                              workdir=llvm_builddir,
+                                              env=merged_env))
+    else:
+        f.addStep(WarningCountingShellCommand(name='make llvm utils build',
+                                              command=['make', 'LLVMX86Utils', '-j8'],
+                                              haltOnFailure=True,
+                                              description='make llvm utils build',
+                                              workdir=llvm_builddir,
+                                              env=merged_env))
 
-    # Add llvm-lit to PATH
-    merged_env.update( { 'PATH' : WithProperties("${PATH}:" + "%(workdir)s/" + llvm_builddir + "/bin")} )
+    # Add clang/llvm-lit to PATH
+    merged_env.update( { 'PATH' : WithProperties("%(workdir)s/" + llvm_builddir + "/bin:" + "${PATH}")} )
 
     # CMake libomp
     f.addStep(ShellCommand(name='cmake libomp',




More information about the llvm-commits mailing list